@@ -570,6 +570,11 @@ impl PackageReadout for LinuxPackageReadout {
                 packages.push((PackageManager::Snap, c));
             }
         }
+        if extra::which("brew") {
+            if let Some(c) = LinuxPackageReadout::count_homebrew() {
+                packages.push((PackageManager::Homebrew, c));
+            }
+        }
 
         packages
     }
@@ -604,7 +609,7 @@ impl LinuxPackageReadout {
         let pacman_dir = Path::new("/var/lib/pacman/local");
         if pacman_dir.exists() {
             if let Ok(read_dir) = read_dir(pacman_dir) {
-                return Some(read_dir.count() - 1);
+                return Some(read_dir.count());
             };
         }
 
@@ -617,7 +622,7 @@ impl LinuxPackageReadout {
         let eopkg_dir = Path::new("/var/lib/eopkg/package");
         if eopkg_dir.exists() {
             if let Ok(read_dir) = read_dir(eopkg_dir) {
-                return Some(read_dir.count() - 1);
+                return Some(read_dir.count());
             };
         }
 
@@ -648,6 +653,49 @@ impl LinuxPackageReadout {
         None
     }
 
+    /// Returns the number of installed packages for systems
+    /// that have `homebrew` installed.
+    fn count_homebrew() -> Option<usize> {
+        if let Ok(home_dir) = std::env::var("HOME") {
+            let linuxbrew = PathBuf::from(home_dir).join(".linuxbrew");
+            if linuxbrew.exists() {
+                let cellar_count = match read_dir(linuxbrew.join("Cellar")) {
+                    Ok(read_dir) => read_dir.filter(|x| {
+                        if let Ok(entry) = x {
+                            if entry.path().ends_with(".keepme") {
+                                return false;
+                            }
+
+                            return true;
+                        }
+
+                        return false;
+                    }).count(),
+                    Err(_) => 0,
+                };
+
+                let global_count = match read_dir(linuxbrew) {
+                    Ok(read_dir) => read_dir.filter(|x| {
+                        if let Ok(entry) = x {
+                            if entry.path().is_dir() {
+                                return false;
+                            }
+
+                            return true;
+                        }
+
+                        return false;
+                    }).count(),
+                    Err(_) => 0,
+                };
+
+                return Some(cellar_count + global_count)
+            }
+        }
+
+        None
+    }
+
     /// Returns the number of installed packages for systems
     /// that utilize `portage` as their package manager.
     fn count_portage() -> Option<usize> {
